#!/usr/bin/perl

use strict; use warnings;

use Lingy::Main;

Lingy::Main->new->run(@ARGV);
